@@ -81,9 +81,12 @@ class Condition:
 
     def __repr__(self):
         vars = []
-        for var in self.value:
-            vars.append(str(var))
-        formatted_value = "( " + ", ".join(vars) + " )"
+        if self.value is not None:
+            for var in self.value:
+                vars.append(str(var))
+            formatted_value = "( " + ", ".join(vars) + " )"
+        else:
+            formatted_value = None
         if isinstance(self.operator, str):
             operator = self.operator
         else:
@@ -107,9 +110,14 @@ class Condition:
                 field_with_agg = self.field.aggregation + " ( " + field_with_agg + " )"
         else:
             field_with_agg = field_with_agg
-        where_condition = (
-                field_with_agg + " " + operator + " " + str(formatted_value)
-        )
+        if formatted_value is not None:
+            where_condition = (
+                    field_with_agg + " " + operator + " " + str(formatted_value)
+            )
+        else:
+            where_condition = (
+                    field_with_agg + " " + operator
+            )
 
         return where_condition
 
